@@ -1,4 +1,4 @@
-from blazeweb import db
+from compstack.sqlalchemy import db
 from model.orm import AuditRecord
 
 def create_audit_record(identifier, user_id, audit_text, comments, commit_trans=False):
@@ -21,7 +21,7 @@ def create_audit_record(identifier, user_id, audit_text, comments, commit_trans=
         raise
 
     return ar
-    
+
 def audit_record_get(oid=None):
     return db.sess.query(AuditRecord).get(oid)
 
@@ -31,4 +31,3 @@ def get_audit_record_list(identifier):
 def get_previous_audit_record(rev_id):
     a = audit_record_get(rev_id)
     return db.sess.query(AuditRecord).filter(AuditRecord.identifier==a.identifier).filter(AuditRecord.createdts<=a.createdts).filter(AuditRecord.id<a.id).order_by(AuditRecord.createdts.desc(), AuditRecord.id.desc()).first()
-    
\ No newline at end of file
